@@ -9,9 +9,10 @@ class BookLoadNotification:
 
   def send(self, load_id, user_id):
     message = '{' + f'"userId" : {user_id}, ' \
-                    f'"load_id": "{load_id}", ' \
+                    f'"loadId": "{load_id}", ' \
                     f'"subject" : "{self._app_config.BOOK_LOAD_SNS_SUBJECT}", ' \
                     f'"className":  "{self._app_config.BOOK_LOAD_SNS_CLASS_NAME}"' + '}'
+    print(f"sending messsage {message} to {self._app_config.BOOK_LOAD_SNS_TOPIC_ARN}")
     sns_service = SnsService()
     sns_service.send(self._app_config.BOOK_LOAD_SNS_TOPIC_ARN,
       self._app_config.BOOK_LOAD_SNS_SUBJECT, message)
